==> haskell-http-types-0.12.4-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
key:                  http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  d5cf05006667f29b35df211ec1df2f5b
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.4-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
key:                  http-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  7b875830c6790d0a69cbe2986144c73d
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3FuXchFPXBfLVJKu7fam1O text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
